pub struct ServerData { /* private fields */ }
Data of a single server

Implementations

source

impl ServerData

Auto-generated by derive_getters::Getters.

source

pub fn name(&self) -> &String

Get field name from instance of ServerData.

Examples found in repository?
examples/serverlist.rs (line 10)
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
fn main() {
    let api = BBApi::new();
    let server_list = api.server_list()
        .expect("Retrieving server list");

    server_list.into_iter().for_each(|server| {
        println!("{} [{}, {}, {}] ({}, {}, {})", 
            server.name(), 
            server.gamemode(), 
            server.map(),
            server.map_size(),
            server.hz(), 
            server.anti_cheat(),
            server.build()
        )
    });
}
source

pub fn map(&self) -> &String

Get field map from instance of ServerData.

Examples found in repository?
examples/serverlist.rs (line 12)
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
fn main() {
    let api = BBApi::new();
    let server_list = api.server_list()
        .expect("Retrieving server list");

    server_list.into_iter().for_each(|server| {
        println!("{} [{}, {}, {}] ({}, {}, {})", 
            server.name(), 
            server.gamemode(), 
            server.map(),
            server.map_size(),
            server.hz(), 
            server.anti_cheat(),
            server.build()
        )
    });
}
source

pub fn map_size(&self) -> &MapSize

Get field map_size from instance of ServerData.

Examples found in repository?
examples/serverlist.rs (line 13)
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
fn main() {
    let api = BBApi::new();
    let server_list = api.server_list()
        .expect("Retrieving server list");

    server_list.into_iter().for_each(|server| {
        println!("{} [{}, {}, {}] ({}, {}, {})", 
            server.name(), 
            server.gamemode(), 
            server.map(),
            server.map_size(),
            server.hz(), 
            server.anti_cheat(),
            server.build()
        )
    });
}
source

pub fn gamemode(&self) -> &Gamemode

Get field gamemode from instance of ServerData.

Examples found in repository?
examples/serverlist.rs (line 11)
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
fn main() {
    let api = BBApi::new();
    let server_list = api.server_list()
        .expect("Retrieving server list");

    server_list.into_iter().for_each(|server| {
        println!("{} [{}, {}, {}] ({}, {}, {})", 
            server.name(), 
            server.gamemode(), 
            server.map(),
            server.map_size(),
            server.hz(), 
            server.anti_cheat(),
            server.build()
        )
    });
}
source

pub fn region(&self) -> &Region

Get field region from instance of ServerData.

source

pub fn player_count(&self) -> &u8

Get field player_count from instance of ServerData.
SAFETY: Unless Battlebit upgrades their engine, this number should fit into a u8.

source

pub fn queued_player_count(&self) -> &u16

Get field queued_player_count from instance of ServerData.
SAFETY: The queued player count should realistically never reach 65_535.

source

pub fn max_players(&self) -> &u8

Get field max_players from instance of ServerData.
SAFETY: Unless Battlebit upgrades their engine, this number should fit into a u8.

source

pub fn hz(&self) -> &u8

Get field hz from instance of ServerData.
SAFETY: Unless Battlebit upgrades their engine, this number should fit into a u8.

Examples found in repository?
examples/serverlist.rs (line 14)
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
fn main() {
    let api = BBApi::new();
    let server_list = api.server_list()
        .expect("Retrieving server list");

    server_list.into_iter().for_each(|server| {
        println!("{} [{}, {}, {}] ({}, {}, {})", 
            server.name(), 
            server.gamemode(), 
            server.map(),
            server.map_size(),
            server.hz(), 
            server.anti_cheat(),
            server.build()
        )
    });
}
source

pub fn day_night(&self) -> &DayNight

Get field day_night from instance of ServerData.

source

pub fn is_official(&self) -> &bool

Get field is_official from instance of ServerData.

source

pub fn has_password(&self) -> &bool

Get field has_password from instance of ServerData.

source

pub fn anti_cheat(&self) -> &AntiCheat

Get field anti_cheat from instance of ServerData.

Examples found in repository?
examples/serverlist.rs (line 15)
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
fn main() {
    let api = BBApi::new();
    let server_list = api.server_list()
        .expect("Retrieving server list");

    server_list.into_iter().for_each(|server| {
        println!("{} [{}, {}, {}] ({}, {}, {})", 
            server.name(), 
            server.gamemode(), 
            server.map(),
            server.map_size(),
            server.hz(), 
            server.anti_cheat(),
            server.build()
        )
    });
}
source

pub fn build(&self) -> &String

Get field build from instance of ServerData.

Examples found in repository?
examples/serverlist.rs (line 16)
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
fn main() {
    let api = BBApi::new();
    let server_list = api.server_list()
        .expect("Retrieving server list");

    server_list.into_iter().for_each(|server| {
        println!("{} [{}, {}, {}] ({}, {}, {})", 
            server.name(), 
            server.gamemode(), 
            server.map(),
            server.map_size(),
            server.hz(), 
            server.anti_cheat(),
            server.build()
        )
    });
}
source

impl ServerData

source

pub fn has_unknown(&self) -> bool

Small check if this ServerData has Unknown fields.
Mostly used by me to check if this API client is outdated.